@@ -1,6 +1,6 @@
 # Requires input to be character
 p_load_single_gh <- 
-function (package, install = TRUE, ...){
+function (package, install = TRUE, dependencies = TRUE, ...){
 
     ## isolate package name from script
     pack <- parse_git_repo(package)[["repo"]]
@@ -12,7 +12,7 @@ function (package, install = TRUE, ...){
 
     # Loaded failed - attempt to install
     if(install){
-        p_install_gh(package, ...) 
+        p_install_gh(package, dependencies, ...) 
         return(suppressWarnings(require(pack, character.only = TRUE)))
     }
 
