@@ -13,6 +13,7 @@
 #' @author juba (stackoverflow.com) and Dason Kurkiewicz
 #' @references \url{http://stackoverflow.com/a/14896943/1003565}
 p_temp <- function(package, character.only = FALSE){
+    
     if(!character.only){
         package <- as.character(substitute(package))
     }
@@ -21,16 +22,18 @@ p_temp <- function(package, character.only = FALSE){
     # the logic being that this will be wiped eventually
     temppath <- tempdir()
     currentLibPaths <- .libPaths()
+    
     # Add the temp path to libPaths so that it can be loaded...
     if(!temppath %in% currentLibPaths){
         .libPaths(c(currentLibPaths, temppath))
     }
     # Install into the temppath
     p_install(package, character.only = TRUE, lib = temppath)
+    
     # load the package
     # NOTE: Is there a reason to use or not to use p_load?
-    require(package, character.only = TRUE)
+    #require(package, character.only = TRUE)
     
-    invisible(p_load_single(package))
+    invisible(p_load_single(package, lib = temppath))
 
 }
